@@ -331,7 +331,7 @@ dimnames.DBIrepdesign<-function(x){
 
 
 svrepdesign.character<-function (variables=NULL,repweights=NULL, weights=NULL,
-                                 data=NULL,type=c("BRR","Fay","JK1", "JKn","bootstrap","ACS","successive-difference","JK2","other"),
+                                 data=NULL, degf=NULL,type=c("BRR","Fay","JK1", "JKn","bootstrap","ACS","successive-difference","JK2","other"),
                                  combined.weights=TRUE, rho=NULL, bootstrap.average=NULL,
                                  scale=NULL,rscales=NULL,fpc=NULL, fpctype=c("fraction","correction"),
                                  mse=getOption("survey.replicates.mse"),dbtype="SQLite", dbname,
@@ -356,7 +356,7 @@ svrepdesign.character<-function (variables=NULL,repweights=NULL, weights=NULL,
     
     design.data<-DBI::dbGetQuery(dbconn, design.query)
     
-  rval<-svrepdesign(variables=variables,repweights=repweights, weights=weights, type=type,
+  rval<-svrepdesign(variables=variables,repweights=repweights, weights=weights, degf=NULL, type=type,
                     data=design.data,
                     combined.weights=combined.weights, rho=rho, bootstrap.average=NULL,
                     scale=scale,rscales=rscales,fpc=fpc, fpctype=c("fraction","correction"), mse=mse)
