@@ -4,6 +4,7 @@ make.formula<-function(names) formula(paste("~",paste(names,collapse="+")))
 dimnames.survey.design<-function(x) dimnames(x$variables)
 dimnames.svyrep.design<-function(x) dimnames(x$variables)
 dimnames.twophase<-function(x) dimnames(x$phase1$sample$variables)
+dimnames.twophase2<-function(x) dimnames(x$phase1$full$variables)
 
 oldsvydesign<-function(ids,probs=NULL,strata=NULL,variables=NULL, fpc=NULL,
                     data=NULL, nest=FALSE, check.strata=!nest,weights=NULL){
@@ -1735,7 +1736,9 @@ model.frame.survey.design2<-function(formula,...){
   if (is.null(getOption("survey.multicore")))
     options(survey.multicore=FALSE)
   if (is.null(getOption("survey.replicates.mse")))
-    options(survey.replicates.mse=FALSE)
+      options(survey.replicates.mse=FALSE)
+  if (is.null(getOption("survey.use_rcpp")))
+      options(survey.use_rcpp=TRUE)
 }
 
 
