@@ -3,7 +3,7 @@ svyttest<-function(formula, design,...) UseMethod("svyttest",design)
 svyttest.default<-function(formula, design, ...){
   if (formula[[3]]==1 || formula[[3]]==0){
     ## one-sample
-    tt <- eval(bquote(svymean(~.(formula[[2]]),design,...)))
+    tt <- eval(bquote(svymean(~as.numeric(.(formula[[2]])),design,...)))
     rval<-list(statistic=coef(tt)[1]/SE(tt)[1],
                parameter=degf(design)-1,
                estimate=coef(tt)[1],
@@ -22,7 +22,10 @@ svyttest.default<-function(formula, design, ...){
     class(rval)<-c("svyttest","htest")
   } else {
     ## two-sample
-    m <- eval(bquote(svyglm(formula,design, family=gaussian())))
+      m <- eval(bquote(svyglm(formula,design, family=gaussian())))
+      mm<-model.matrix(m)
+      if( (ncol(mm)!=2) || (any(!(mm[,2] %in% c(0,1))) && any(!(mm[,2] %in% c(1,2)))))
+          stop("group must be binary")
     rval<-list(statistic=coef(m)[2]/SE(m)[2],
                parameter=m$df.resid,
                estimate=coef(m)[2],
@@ -100,7 +103,7 @@ svyciprop<-function(formula, design, method=c("logit","likelihood","asin","beta"
   }
   halfalpha<-(1-level)/2
   names(ci)<-paste(round(c(halfalpha,(1-halfalpha))*100,1),"%",sep="")
-  names(rval)<-deparse(formula[[2]])
+  names(rval)<-paste(deparse(formula[[2]]), collapse="")
   attr(rval,"ci")<-ci
   class(rval)<-"svyciprop"
   rval
@@ -119,7 +122,7 @@ vcov.svyciprop<-function(object,...) attr(object,"var")
 
 print.svyciprop<-function(x,digits=max(3,getOption("digits")-4),...){
   m <- cbind(coef(x), confint(x))
-  printCoefmat(m,digits=digits)
+  printCoefmat(m,digits=digits, cs.ind=1:3,tst.ind=NULL)
   invisible(x)
 }
 
